@@ -217,6 +217,36 @@ class IdentitiesManager(BoundConnections):
       return(errorInSetInfo)
 
 
+   def checkScriptPaths(self):
+      errorInCheckScriptPaths = False
+      if not os.path.exists(self.generateGridProxyPath):
+         self.logger.log(logging.ERROR,getLogMessage("Grid Proxy Generator: %s does not exist." % (self.generateGridProxyPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.generateVomsProxyPath):
+         self.logger.log(logging.ERROR,getLogMessage("VOMS Proxy Generator: %s does not exist." % (self.generateVomsProxyPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.personalizeCopyProxyPath):
+         self.logger.log(logging.ERROR,getLogMessage("Personzlize Copy Proxy: %s does not exist." % (self.personalizeCopyProxyPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.personalizeSAMLProxyPath):
+         self.logger.log(logging.ERROR,getLogMessage("Personzlize SAML Proxy: %s does not exist." % (self.personalizeSAMLProxyPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.refreshCondorproxyPath):
+         self.logger.log(logging.ERROR,getLogMessage("Refresh Condor Proxy: %s does not exist." % (self.refreshCondorproxyPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.refreshJobmonProxyPath):
+         self.logger.log(logging.ERROR,getLogMessage("Refresh JobMon Proxy: %s does not exist." % (self.refreshJobmonProxyPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.genUserIDPath):
+         self.logger.log(logging.ERROR,getLogMessage("User Id Generator: %s does not exist." % (self.genUserIDPath)))
+         errorInCheckScriptPaths = True
+      if not os.path.exists(self.genUserPKIPath):
+         self.logger.log(logging.ERROR,getLogMessage("User PKI Generator: %s does not exist." % (self.genUserPKIPath)))
+         errorInCheckScriptPaths = True
+
+      return(errorInCheckScriptPaths)
+
+
    def terminate(self):
       if not self.terminating:
          self.closeListeningConnection()
@@ -312,13 +342,16 @@ class IdentitiesManager(BoundConnections):
                self.logger.log(logging.ERROR,getLogMessage(stdOutput.strip()))
             if stdError:
                self.logger.log(logging.ERROR,getLogMessage(stdError.strip()))
+            interval = 60.*self.identitiesInfo.getIdentityKeyValue(identityName,'communityRefreshInterval')* \
+                           self.identitiesInfo.getIdentityKeyValue(identityName,'communityRefreshOnFailFactor')
          else:
             self.logger.log(logging.INFO,getLogMessage("Identity manager %s proxy generated" % (identityName)))
             interval = 60.*self.identitiesInfo.getIdentityKeyValue(identityName,'communityRefreshInterval')
-            generateProxyEvent = self.Event(self.EVENTGENERATEGRIDPROXY,
-                                            identityName,
-                                            now+interval)
-            self.eventQueue.add(generateProxyEvent)
+
+         generateProxyEvent = self.Event(self.EVENTGENERATEGRIDPROXY,
+                                         identityName,
+                                         now+interval)
+         self.eventQueue.add(generateProxyEvent)
 
 
    def generateCommunityGridProxies(self):
@@ -344,13 +377,16 @@ class IdentitiesManager(BoundConnections):
                self.logger.log(logging.ERROR,getLogMessage(stdOutput.strip()))
             if stdError:
                self.logger.log(logging.ERROR,getLogMessage(stdError.strip()))
+            interval = 60.*self.identitiesInfo.getIdentityKeyValue(identityName,'communityRefreshInterval')* \
+                           self.identitiesInfo.getIdentityKeyValue(identityName,'communityRefreshOnFailFactor')
          else:
             self.logger.log(logging.INFO,getLogMessage("Identity manager %s proxy generated" % (identityName)))
             interval = 60.*self.identitiesInfo.getIdentityKeyValue(identityName,'communityRefreshInterval')
-            generateProxyEvent = self.Event(self.EVENTGENERATEVOMSPROXY,
-                                            identityName,
-                                            now+interval)
-            self.eventQueue.add(generateProxyEvent)
+
+         generateProxyEvent = self.Event(self.EVENTGENERATEVOMSPROXY,
+                                         identityName,
+                                         now+interval)
+         self.eventQueue.add(generateProxyEvent)
 
 
    def generateCommunityVomsProxies(self):
@@ -486,13 +522,16 @@ class IdentitiesManager(BoundConnections):
             self.logger.log(logging.ERROR,getLogMessage(stdOutput.strip()))
          if stdError:
             self.logger.log(logging.ERROR,getLogMessage(stdError.strip()))
+         interval = 60.*identityRefreshProxyInfo['refreshInterval']* \
+                        identityRefreshProxyInfo['refreshOnFailFactor']
       else:
          self.logger.log(logging.INFO,getLogMessage("Identity manager %s user proxies refreshed" % (identityName)))
          interval = 60.*identityRefreshProxyInfo['refreshInterval']
-         scheduleRefreshEvent = self.Event(self.EVENTREFRESHCONDORPROXY,
-                                           identityName,
-                                           now+interval)
-         self.eventQueue.add(scheduleRefreshEvent)
+
+      scheduleRefreshEvent = self.Event(self.EVENTREFRESHCONDORPROXY,
+                                        identityName,
+                                        now+interval)
+      self.eventQueue.add(scheduleRefreshEvent)
 
 
    def refreshUserJobMonitorProxies(self,
@@ -523,13 +562,16 @@ class IdentitiesManager(BoundConnections):
             self.logger.log(logging.ERROR,getLogMessage(stdOutput.strip()))
          if stdError:
             self.logger.log(logging.ERROR,getLogMessage(stdError.strip()))
+         interval = 60.*identityRefreshProxyInfo['refreshInterval']* \
+                        identityRefreshProxyInfo['refreshOnFailFactor']
       else:
          self.logger.log(logging.INFO,getLogMessage("Identity manager %s user proxies refreshed" % (identityName)))
          interval = 60.*identityRefreshProxyInfo['refreshInterval']
-         scheduleRefreshEvent = self.Event(self.EVENTREFRESHJOBMONPROXY,
-                                           identityName,
-                                           now+interval)
-         self.eventQueue.add(scheduleRefreshEvent)
+
+      scheduleRefreshEvent = self.Event(self.EVENTREFRESHJOBMONPROXY,
+                                        identityName,
+                                        now+interval)
+      self.eventQueue.add(scheduleRefreshEvent)
 
 
    def generatePersonalSSHKeyCopy(self,
@@ -619,6 +661,8 @@ class IdentitiesManager(BoundConnections):
    def generatePersonalIdentity(self,
                                 identityName,
                                 hubUserName):
+#     self.logger.log(logging.DEBUG,getLogMessage("generatePersonalIdentity():identityName = " + identityName))
+#     self.logger.log(logging.DEBUG,getLogMessage("generatePersonalIdentity():hubUserName  = " + hubUserName))
       identityPath = ""
       identityType = self.identitiesInfo.getIdentityKeyValue(identityName,'identityType')
       if   identityType == 'x509':
@@ -631,6 +675,8 @@ class IdentitiesManager(BoundConnections):
          identityPath = self.generatePersonalSSHKeyCopy(identityName,hubUserName)
       elif identityType == 'personalPKI':
          identityPath = self.generatePersonalSSHKeyPair(identityName,hubUserName)
+#     self.logger.log(logging.DEBUG,getLogMessage("generatePersonalIdentity():identityType = " + identityType))
+#     self.logger.log(logging.DEBUG,getLogMessage("generatePersonalIdentity():identityPath = " + identityPath))
 
       return(identityType,identityPath)
 
