@@ -34,6 +34,8 @@ from hubzero.submit.LogMessage        import getLogJobIdMessage as getLogMessage
 from hubzero.submit.ParameterTemplate import ParameterTemplate
 
 class RemoteInstantSCRIPT:
+   SUBMISSIONSCRIPTCOMMANDPREFIX = ''
+
    def __init__(self,
                 hubUserName,
                 hubUserId,
@@ -50,30 +52,31 @@ class RemoteInstantSCRIPT:
                 nNodes,
                 ppn,
                 timeHistoryLogs):
-      self.logger                = logging.getLogger(__name__)
-      self.hubUserName           = hubUserName
-      self.hubUserId             = hubUserId
-      self.submitterClass        = submitterClass
-      self.runName               = runName
-      self.localJobId            = localJobId
-      self.instanceId            = instanceId
-      self.workingDirectory      = workingDirectory
-      self.appScriptName         = appScriptName
-      self.isMultiCoreRequest    = isMultiCoreRequest
-      self.computationMode       = managerInfo['computationMode']
-      self.preManagerCommands    = managerInfo['preManagerCommands']
-      self.managerCommand        = managerInfo['managerCommand']
-      self.postManagerCommands   = managerInfo['postManagerCommands']
-      self.nNodes                = nNodes
-      self.ppn                   = ppn
-      self.venue                 = siteInfo['venue']
-      self.venues                = siteInfo['venues']
-      self.venueIndex            = siteInfo['venueIndex']
-      self.submissionScriptsInfo = submissionScriptsInfo
-      self.timestampStart        = timeHistoryLogs['timestampStart']
-      self.timestampFinish       = timeHistoryLogs['timestampFinish']
-      self.timestampTransferred  = timeHistoryLogs['timestampTransferred']
-      self.timeResults           = timeHistoryLogs['timeResults']
+      self.logger                   = logging.getLogger(__name__)
+      self.hubUserName              = hubUserName
+      self.hubUserId                = hubUserId
+      self.submitterClass           = submitterClass
+      self.runName                  = runName
+      self.localJobId               = localJobId
+      self.instanceId               = instanceId
+      self.workingDirectory         = workingDirectory
+      self.appScriptName            = appScriptName
+      self.isMultiCoreRequest       = isMultiCoreRequest
+      self.computationMode          = managerInfo['computationMode']
+      self.preManagerCommands       = managerInfo['preManagerCommands']
+      self.managerCommand           = managerInfo['managerCommand']
+      self.postManagerCommands      = managerInfo['postManagerCommands']
+      self.nNodes                   = nNodes
+      self.ppn                      = ppn
+      self.venue                    = siteInfo['venue']
+      self.venues                   = siteInfo['venues']
+      self.venueIndex               = siteInfo['venueIndex']
+      self.submissionScriptCommands = siteInfo['submissionScriptCommands']
+      self.submissionScriptsInfo    = submissionScriptsInfo
+      self.timestampStart           = timeHistoryLogs['timestampStart']
+      self.timestampFinish          = timeHistoryLogs['timestampFinish']
+      self.timestampTransferred     = timeHistoryLogs['timestampTransferred']
+      self.timeResults              = timeHistoryLogs['timeResults']
 
       self.nodeFileName = ""
       self.nodeList     = []
@@ -82,25 +85,35 @@ class RemoteInstantSCRIPT:
    def __buildMPIFile(self):
       rawSubmissionScript = self.submissionScriptsInfo.getSubmissionScript('Instant','SCRIPT','mpi')
 
+      commandsSCRIPT = ""
+      if self.submissionScriptCommands:
+         if self.SUBMISSIONSCRIPTCOMMANDPREFIX:
+            commandSeparator = "\n%s " % self.SUBMISSIONSCRIPTCOMMANDPREFIX
+            commandsSCRIPT = self.SUBMISSIONSCRIPTCOMMANDPREFIX + " " + commandSeparator.join(self.submissionScriptCommands)
+         else:
+            commandSeparator = "\n"
+            commandsSCRIPT = commandSeparator.join(self.submissionScriptCommands)
+
       substitutions = {}
-      substitutions["PREMANAGERCOMMANDS"]  = "\n".join(self.preManagerCommands)
-      substitutions["MANAGERCOMMAND"]      = self.managerCommand
-      substitutions["POSTMANAGERCOMMANDS"] = "\n".join(self.postManagerCommands)
-      substitutions["NNODES"]              = self.nNodes
+      substitutions["PREMANAGERCOMMANDS"]       = "\n".join(self.preManagerCommands)
+      substitutions["MANAGERCOMMAND"]           = self.managerCommand
+      substitutions["POSTMANAGERCOMMANDS"]      = "\n".join(self.postManagerCommands)
+      substitutions["NNODES"]                   = self.nNodes
       nProcessors = str(int(self.nNodes)*int(self.ppn))
-      substitutions["NPROCESSORS"]         = nProcessors
-      substitutions["APPSCRIPTNAME"]       = self.appScriptName
-      substitutions["TS_TRANSFERRED"]      = self.timestampTransferred
-      substitutions["TS_START"]            = self.timestampStart
-      substitutions["TS_FINISH"]           = self.timestampFinish
-      substitutions["TIME_RESULTS"]        = self.timeResults
-      substitutions["RUNNAME"]             = self.runName
-      substitutions["JOBID"]               = self.localJobId
-      substitutions["INSTANCEID"]          = self.instanceId
-      substitutions["WORKINGDIRECTORY"]    = self.workingDirectory
-      substitutions["NODEFILE"]            = self.nodeFileName
-      substitutions["HUBUSERNAME"]         = self.hubUserName
-      substitutions["HUBUSERID"]           = str(self.hubUserId)
+      substitutions["NPROCESSORS"]              = nProcessors
+      substitutions["APPSCRIPTNAME"]            = self.appScriptName
+      substitutions["TS_TRANSFERRED"]           = self.timestampTransferred
+      substitutions["TS_START"]                 = self.timestampStart
+      substitutions["TS_FINISH"]                = self.timestampFinish
+      substitutions["TIME_RESULTS"]             = self.timeResults
+      substitutions["RUNNAME"]                  = self.runName
+      substitutions["JOBID"]                    = self.localJobId
+      substitutions["INSTANCEID"]               = self.instanceId
+      substitutions["WORKINGDIRECTORY"]         = self.workingDirectory
+      substitutions["NODEFILE"]                 = self.nodeFileName
+      substitutions["HUBUSERNAME"]              = self.hubUserName
+      substitutions["HUBUSERID"]                = str(self.hubUserId)
+      substitutions["SUBMISSIONSCRIPTCOMMANDS"] = commandsSCRIPT
 
       template = ParameterTemplate(rawSubmissionScript)
       try:
@@ -111,6 +124,10 @@ class RemoteInstantSCRIPT:
       except TypeError,err:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
+      else:
+         if self.SUBMISSIONSCRIPTCOMMANDPREFIX:
+            submissionScript = re.sub("(\n)*\n%s" % (self.SUBMISSIONSCRIPTCOMMANDPREFIX),
+                                           "\n%s" % (self.SUBMISSIONSCRIPTCOMMANDPREFIX),submissionScript)
 
       return(submissionScript)
 
@@ -137,17 +154,27 @@ class RemoteInstantSCRIPT:
    def __buildMatlabPCTFile(self):
       rawSubmissionScript = self.submissionScriptsInfo.getSubmissionScript('Instant','SCRIPT','matlabpct')
 
+      commandsSCRIPT = ""
+      if self.submissionScriptCommands:
+         if self.SUBMISSIONSCRIPTCOMMANDPREFIX:
+            commandSeparator = "\n%s " % self.SUBMISSIONSCRIPTCOMMANDPREFIX
+            commandsSCRIPT = self.SUBMISSIONSCRIPTCOMMANDPREFIX + " " + commandSeparator.join(self.submissionScriptCommands)
+         else:
+            commandSeparator = "\n"
+            commandsSCRIPT = commandSeparator.join(self.submissionScriptCommands)
+
       substitutions = {}
-      substitutions["PREMANAGERCOMMANDS"]  = "\n".join(self.preManagerCommands)
-      substitutions["POSTMANAGERCOMMANDS"] = "\n".join(self.postManagerCommands)
-      substitutions["APPSCRIPTNAME"]       = self.appScriptName
-      substitutions["TS_TRANSFERRED"]      = self.timestampTransferred
-      substitutions["TS_START"]            = self.timestampStart
-      substitutions["TS_FINISH"]           = self.timestampFinish
-      substitutions["TIME_RESULTS"]        = self.timeResults
-      substitutions["WORKINGDIRECTORY"]    = self.workingDirectory
-      substitutions["HUBUSERNAME"]         = self.hubUserName
-      substitutions["HUBUSERID"]           = str(self.hubUserId)
+      substitutions["PREMANAGERCOMMANDS"]       = "\n".join(self.preManagerCommands)
+      substitutions["POSTMANAGERCOMMANDS"]      = "\n".join(self.postManagerCommands)
+      substitutions["APPSCRIPTNAME"]            = self.appScriptName
+      substitutions["TS_TRANSFERRED"]           = self.timestampTransferred
+      substitutions["TS_START"]                 = self.timestampStart
+      substitutions["TS_FINISH"]                = self.timestampFinish
+      substitutions["TIME_RESULTS"]             = self.timeResults
+      substitutions["WORKINGDIRECTORY"]         = self.workingDirectory
+      substitutions["HUBUSERNAME"]              = self.hubUserName
+      substitutions["HUBUSERID"]                = str(self.hubUserId)
+      substitutions["SUBMISSIONSCRIPTCOMMANDS"] = commandsSCRIPT
 
       template = ParameterTemplate(rawSubmissionScript)
       try:
@@ -158,6 +185,10 @@ class RemoteInstantSCRIPT:
       except TypeError,err:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
+      else:
+         if self.SUBMISSIONSCRIPTCOMMANDPREFIX:
+            submissionScript = re.sub("(\n)*\n%s" % (self.SUBMISSIONSCRIPTCOMMANDPREFIX),
+                                           "\n%s" % (self.SUBMISSIONSCRIPTCOMMANDPREFIX),submissionScript)
 
       return(submissionScript)
 
