@@ -65,6 +65,7 @@ class SitesInfo:
                         siteName = sitePattern.match(record).group(2)
                         self.sites[siteName] = {'venues':[],
                                                 'venuePort':22,
+                                                'sshOptions':"",
                                                 'gsiHost':socket.gethostname(),
                                                 'cloudDesignator':'',
                                                 'tunnelDesignator':'',
@@ -80,6 +81,7 @@ class SitesInfo:
                                                 'remoteBatchPartitionSize':'',
                                                 'remoteBatchConstraints':'',
                                                 'parallelEnvironment':'',
+                                                'submissionScriptCommands':[],
                                                 'remoteBinDirectory':os.path.join('${HOME}','bin'),
                                                 'remoteApplicationRootDirectory':'',
                                                 'remoteScratchDirectory':'',
@@ -104,8 +106,7 @@ class SitesInfo:
                                                 'maximumCores':0,
                                                 'minimumCoreWallTime':0.,
                                                 'maximumCoreWallTime':0.,
-                                                'pegasusTemplates':[],
-                                                'pegasusSites':[]
+                                                'pegasusTemplates':[]
                                                }
                      elif keyValuePattern.match(record):
                         key,value = keyValuePattern.match(record).group(2,4)
@@ -229,13 +230,42 @@ class SitesInfo:
                      self.sites[site]['pegasusTemplates']['rc']    = pegasusTemplatePath
                   elif pegasusTemplate.endswith('.xml'):
                      self.sites[site]['pegasusTemplates']['sites'] = pegasusTemplatePath
-                     pegasusSites = []
+                     pegasusSites = {}
                      siteDoc = minidom.parse(pegasusTemplatePath)
                      rootNode = siteDoc.documentElement
                      children = rootNode.getElementsByTagName("site")
                      for child in children:
                         handle = child.getAttribute('handle')
                         if handle != 'local':
+                           pegasusSites[handle] = {}
+                           try:
+                              arch      = child.getAttribute('arch')
+                           except:
+                              pass
+                           else:
+                              pegasusSites[handle]['arch'] = arch
+
+                           try:
+                              osFlavor  = child.getAttribute('os')
+                           except:
+                              pass
+                           else:
+                              pegasusSites[handle]['osFlavor'] = osFlavor
+
+                           try:
+                              osVersion = child.getAttribute('osversion')
+                           except:
+                              pass
+                           else:
+                              pegasusSites[handle]['osVersion'] = osVersion
+
+                           try:
+                              osRelease = child.getAttribute('osrelease')
+                           except:
+                              pass
+                           else:
+                              pegasusSites[handle]['osRelease'] = osRelease
+
                            gridstartDistribute = False
                            for grandChild in child.getElementsByTagName("profile"):
                               if grandChild.nodeType == Node.ELEMENT_NODE:
@@ -246,9 +276,8 @@ class SitesInfo:
                                           gridstart = greatGrandChild.nodeValue
                                           if gridstart == 'Distribute':
                                              gridstartDistribute = True
-                           pegasusSites.append((gridstartDistribute,handle))
-                     pegasusSites.sort()
-                     self.sites[site]['pegasusSites'] = [ handle for gridstartDistribute,handle in pegasusSites ]
+                           pegasusSites[handle]['gridstartDistribute'] = gridstartDistribute
+                     self.sites[site]['pegasusSites'] = pegasusSites
                   elif pegasusTemplate.endswith('.txt'):
                      self.sites[site]['pegasusTemplates']['tc']    = pegasusTemplatePath
                else:
@@ -355,28 +384,6 @@ class SitesInfo:
       for siteName in self.sites:
          site = self.sites[siteName]
          if site['state'] == 'enabled':
-            if   nCores > 0:
-               if nCores < site['minimumCores']:
-                  markedForDeletion.append(siteName)
-               if site['maximumCores'] > 0:
-                  if nCores > site['maximumCores']:
-                     markedForDeletion.append(siteName)
-            elif nCores < 0:
-               markedForDeletion.append(siteName)
-
-            if float(jobWallTime) < site['minimumWallTime']:
-               markedForDeletion.append(siteName)
-            if site['maximumWallTime'] > 0.:
-               if float(jobWallTime) > site['maximumWallTime']:
-                  markedForDeletion.append(siteName)
-
-            jobCoreWallTime = nCores * float(jobWallTime)
-            if jobCoreWallTime < site['minimumCoreWallTime']:
-               markedForDeletion.append(siteName)
-            if site['maximumCoreWallTime'] > 0.:
-               if jobCoreWallTime > site['maximumCoreWallTime']:
-                  markedForDeletion.append(siteName)
-
             members = site['members']
             if len(members) > 0:
                membersMarkedForDeletion = []
@@ -384,13 +391,20 @@ class SitesInfo:
                   if member in self.sites:
                      memberSite = self.sites[member]
                      if memberSite['state'] == 'enabled':
-                        if   nCores > 0:
-                           if nCores < memberSite['minimumCores']:
+                        if nCores == 0:
+                           try:
+                              nMemberSiteCores = int(memberSite['remotePpn'])
+                           except:
+                              nMemberSiteCores = 0
+                        else:
+                           nMemberSiteCores = nCores
+                        if   nMemberSiteCores > 0:
+                           if nMemberSiteCores < memberSite['minimumCores']:
                               membersMarkedForDeletion.append(member)
                            if memberSite['maximumCores'] > 0:
-                              if nCores > memberSite['maximumCores']:
+                              if nMemberSiteCores > memberSite['maximumCores']:
                                  membersMarkedForDeletion.append(member)
-                        elif nCores < 0:
+                        elif nMemberSiteCores < 0:
                            membersMarkedForDeletion.append(member)
 
                         if float(jobWallTime) < memberSite['minimumWallTime']:
@@ -398,12 +412,50 @@ class SitesInfo:
                         if memberSite['maximumWallTime'] > 0.:
                            if float(jobWallTime) > memberSite['maximumWallTime']:
                               membersMarkedForDeletion.append(member)
+
+                        jobCoreWallTime = nMemberSiteCores * float(jobWallTime)
+                        if jobCoreWallTime < memberSite['minimumCoreWallTime']:
+                           membersMarkedForDeletion.append(member)
+                        if site['maximumCoreWallTime'] > 0.:
+                           if jobCoreWallTime > memberSite['maximumCoreWallTime']:
+                              membersMarkedForDeletion.append(member)
+
                for member in membersMarkedForDeletion:
                   if member in site['members']:
                      site['members'].remove(member)
                del membersMarkedForDeletion
                if len(site['members']) == 0:
                   markedForDeletion.append(siteName)
+            else:
+               if nCores == 0:
+                  try:
+                     nSiteCores = int(site['remotePpn'])
+                  except:
+                     nSiteCores = 0
+               else:
+                  nSiteCores = nCores
+               if   nSiteCores > 0:
+                  if nSiteCores < site['minimumCores']:
+                     markedForDeletion.append(siteName)
+                  if site['maximumCores'] > 0:
+                     if nSiteCores > site['maximumCores']:
+                        markedForDeletion.append(siteName)
+               elif nSiteCores < 0:
+                  markedForDeletion.append(siteName)
+
+               if float(jobWallTime) < site['minimumWallTime']:
+                  markedForDeletion.append(siteName)
+               if site['maximumWallTime'] > 0.:
+                  if float(jobWallTime) > site['maximumWallTime']:
+                     markedForDeletion.append(siteName)
+
+               jobCoreWallTime = nSiteCores * float(jobWallTime)
+               if jobCoreWallTime < site['minimumCoreWallTime']:
+                  markedForDeletion.append(siteName)
+               if site['maximumCoreWallTime'] > 0.:
+                  if jobCoreWallTime > site['maximumCoreWallTime']:
+                     markedForDeletion.append(siteName)
+
 
       for siteName in markedForDeletion:
          site = self.sites[siteName]
@@ -641,51 +693,37 @@ class SitesInfo:
       return(members)
 
 
-   def getSitePegasusSite(self,
-                          siteName):
-      selectedPegasusSite = ""
-      if siteName in self.sites:
-         site = self.sites[siteName]
-         if 'pegasusSites' in site:
-            pegasusSites = site['pegasusSites']
-            totalWeightedSum = 0.
-            for pegasusSite in pegasusSites:
-               try:
-                  site,weight = pegasusSite.split(':')
-                  totalWeightedSum += float(weight)
-               except:
-                  pass
-
-            if totalWeightedSum == 0:
-               pegasusIndex = random.randint(0,len(pegasusSites)-1)
-               selectedPegasusSite = pegasusSites[pegasusIndex]
-            else:
-               randomWeight = random.random()
-               weightedSum = 0.
-               for pegasusSite in pegasusSites:
-                  try:
-                     site,weight = pegasusSite.split(':')
-                     if float(weight) > 0.:
-                        weightedSum += float(weight)/totalWeightedSum
-                        if weightedSum >= randomWeight:
-                           selectedPegasusSite = site
-                           break
-                  except:
-                     pass
-
-      return(selectedPegasusSite)
-
-
    def getSitePegasusSites(self,
                            siteName):
-      pegasusSites = ""
+      sitePegasusSites = ""
       if siteName in self.sites:
          site = self.sites[siteName]
          if 'pegasusSites' in site:
             if len(site['pegasusSites']) > 0:
-               pegasusSites = ','.join(site['pegasusSites'])
+               pegasusSites = []
+               for pegasusSite in site['pegasusSites']:
+                  pegasusSites.append((site['pegasusSites'][pegasusSite]['gridstartDistribute'],pegasusSite))
+               pegasusSites.sort()
+               orderedPegasusSites = [ pegasusSite for gridstartDistribute,pegasusSite in pegasusSites ]
+               sitePegasusSites = ','.join(orderedPegasusSites)
 
-      return(pegasusSites)
+      return(sitePegasusSites)
+
+
+   def getSitePegasusSiteAttributeValue(self,
+                                        siteName,
+                                        pegasusSite,
+                                        attribute):
+      sitePegasusSiteAttributeValue = ""
+      if siteName in self.sites:
+         site = self.sites[siteName]
+         if 'pegasusSites' in site:
+            pegasusSites = site['pegasusSites']
+            if pegasusSite in pegasusSites:
+               if attribute in pegasusSites[pegasusSite]:
+                  sitePegasusSiteAttributeValue = pegasusSites[pegasusSite][attribute]
+
+      return(sitePegasusSiteAttributeValue)
 
 
    def getSitesWithKeyValue(self,
@@ -807,6 +845,7 @@ class SitesInfo:
       siteInfo['venueIndex']                       = -1
       siteInfo['venue']                            = "Unknown"
       siteInfo['venuePort']                        = 22
+      siteInfo['sshOptions']                       = ""
       siteInfo['venueMechanism']                   = ''
       siteInfo['cloudDesignator']                  = ""
       siteInfo['tunnelDesignator']                 = ""
@@ -825,6 +864,7 @@ class SitesInfo:
       siteInfo['remoteBatchPartitionSize']         = ""
       siteInfo['remoteBatchConstraints']           = ""
       siteInfo['parallelEnvironment']              = ""
+      siteInfo['submissionScriptCommands']         = []
       siteInfo['remoteBinDirectory']               = ""
       siteInfo['remoteApplicationRootDirectory']   = ""
       siteInfo['remoteScratchDirectory']           = ""
@@ -851,6 +891,7 @@ class SitesInfo:
          siteInfo['venueIndex']                    = -1
          siteInfo['venue']                         = ""
       siteInfo['venuePort']                        = site['venuePort']
+      siteInfo['sshOptions']                       = site['sshOptions']
       siteInfo['gsiHost']                          = site['gsiHost']
 
       siteInfo['venueMechanism']                   = site['venueMechanism']
@@ -876,6 +917,7 @@ class SitesInfo:
       siteInfo['remoteBatchPartitionSize']         = site['remoteBatchPartitionSize']
       siteInfo['remoteBatchConstraints']           = site['remoteBatchConstraints']
       siteInfo['parallelEnvironment']              = site['parallelEnvironment']
+      siteInfo['submissionScriptCommands']         = site['submissionScriptCommands']
       siteInfo['remoteBinDirectory']               = site['remoteBinDirectory']
       siteInfo['remoteApplicationRootDirectory']   = site['remoteApplicationRootDirectory']
       siteInfo['remoteScratchDirectory']           = site['remoteScratchDirectory']
