@@ -1,30 +1,31 @@
 # @package      hubzero-submit-distributor
 # @file         ToolsInfo.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
-# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+# @copyright    Copyright (c) 2012-2015 HUBzero Foundation, LLC.
+# @license      http://opensource.org/licenses/MIT MIT
 #
-# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2015 HUBzero Foundation, LLC.
 #
-# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
 #
-# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
-# software: you can redistribute it and/or modify it under the terms of
-# the GNU Lesser General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any
-# later version.
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
 #
-# HUBzero is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
 #
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
-
 import os.path
 import re
 import random
@@ -35,8 +36,7 @@ from hubzero.submit.GroupMembership import isGroupMember
 
 class ToolsInfo:
    def __init__(self,
-                infoDirectory,
-                toolsFile):
+                toolsPath):
       self.logger     = logging.getLogger(__name__)
       self.tools      = {}
 
@@ -45,60 +45,85 @@ class ToolsInfo:
       commentPattern  = re.compile('\s*#.*')
       toolName        = ""
 
-      toolsPath = os.path.join(infoDirectory,toolsFile)
       if os.path.exists(toolsPath):
-         fpInfo = open(toolsPath,'r')
-         if fpInfo:
-            eof = False
-            while not eof:
-               record = fpInfo.readline()
-               if record != "":
-                  record = commentPattern.sub("",record)
-                  if   toolPattern.match(record):
-                     toolName = toolPattern.match(record).group(2)
-                     if not toolName in self.tools:
-                        self.tools[toolName] = []
-                     toolGroupIndex = len(self.tools[toolName])
-                     self.tools[toolName].append({'destinations':[],
-                                                  'executablePath':'',
-                                                  'isMPI':'',
-                                                  'restrictedToUsers':[],
-                                                  'restrictedToGroups':[],
-                                                  'environment':[],
-                                                  'remoteManager':'',
-                                                  'state':'enabled'
-                                                 })
-                  elif keyValuePattern.match(record):
-                     key,value = keyValuePattern.match(record).group(2,4)
-                     if key in self.tools[toolName][toolGroupIndex]:
-                        if   isinstance(self.tools[toolName][toolGroupIndex][key],list):
-                           self.tools[toolName][toolGroupIndex][key] = [e.strip() for e in value.split(',')]
-                        elif isinstance(self.tools[toolName][toolGroupIndex][key],dict):
-                           dictKey,dictValue = value.split(':')
-                           self.tools[toolName][toolGroupIndex][key][dictKey.strip()] = dictValue.strip()
-                        elif isinstance(self.tools[toolName][toolGroupIndex][key],bool):
-                           self.tools[toolName][toolGroupIndex][key] = bool(value.lower() == 'true')
+         try:
+            fpInfo = open(toolsPath,'r')
+            try:
+               eof = False
+               while not eof:
+                  record = fpInfo.readline()
+                  if record != "":
+                     record = commentPattern.sub("",record)
+                     if   toolPattern.match(record):
+                        toolName = toolPattern.match(record).group(2)
+                        if not toolName in self.tools:
+                           self.tools[toolName] = []
+                        toolGroupIndex = len(self.tools[toolName])
+                        self.tools[toolName].append({'destinations':[],
+                                                     'executablePath':'',
+                                                     'restrictedToUsers':[],
+                                                     'restrictedToGroups':[],
+                                                     'environment':[],
+                                                     'remoteManager':'',
+                                                     'state':'enabled'
+                                                    })
+                     elif keyValuePattern.match(record):
+                        key,value = keyValuePattern.match(record).group(2,4)
+                        if key in self.tools[toolName][toolGroupIndex]:
+                           if   isinstance(self.tools[toolName][toolGroupIndex][key],list):
+                              self.tools[toolName][toolGroupIndex][key] = [e.strip() for e in value.split(',')]
+                           elif isinstance(self.tools[toolName][toolGroupIndex][key],bool):
+                              self.tools[toolName][toolGroupIndex][key] = bool(value.lower() == 'true')
+                           elif isinstance(self.tools[toolName][toolGroupIndex][key],float):
+                              self.tools[toolName][toolGroupIndex][key] = float(value)
+                           elif isinstance(self.tools[toolName][toolGroupIndex][key],int):
+                              self.tools[toolName][toolGroupIndex][key] = int(value)
+                           elif isinstance(self.tools[toolName][toolGroupIndex][key],dict):
+                              try:
+                                 sampleKey   = self.tools[toolName][toolGroupIndex][key].keys()[0]
+                                 sampleValue = self.tools[toolName][toolGroupIndex][key][sampleKey]
+                              except:
+                                 sampleKey   = "key"
+                                 sampleValue = "value"
+                              self.tools[toolName][toolGroupIndex][key] = {}
+                              for e in value.split(','):
+                                 dictKey,dictValue = e.split(':')
+                                 if isinstance(sampleKey,int):
+                                    dictKey = int(dictKey)
+                                 if   isinstance(sampleValue,int):
+                                    dictValue = int(dictValue)
+                                 elif isinstance(sampleValue,float):
+                                    dictValue = float(dictValue)
+                                 elif isinstance(sampleValue,bool):
+                                    dictValue = bool(dictValue.lower() == 'true')
+                                 self.tools[toolName][toolGroupIndex][key][dictKey] = dictValue
+                           else:
+                              self.tools[toolName][toolGroupIndex][key] = value
                         else:
-                           self.tools[toolName][toolGroupIndex][key] = value
-                     else:
-                        self.logger.log(logging.WARNING,getLogMessage("Undefined tool key %s %s in tool %s" % (key,value,toolName)))
-               else:
-                  eof = True
-            fpInfo.close()
-
-         for toolName in self.tools:
-            markedForDeletion = []
-            for toolGroupIndex in xrange(len(self.tools[toolName])):
-               state = self.tools[toolName][toolGroupIndex]['state']
-               if state == 'disabled':
-                  markedForDeletion.append(toolGroupIndex)
-            markedForDeletion.reverse()
-            for toolGroupIndex in markedForDeletion:
-               del self.tools[toolName][toolGroupIndex]
-            del markedForDeletion
+                           self.logger.log(logging.WARNING,getLogMessage("Undefined tool key %s %s in tool %s" % \
+                                                                                            (key,value,toolName)))
+                  else:
+                     eof = True
+            except (IOError,OSError):
+               self.logger.log(logging.ERROR,getLogMessage("Tools configuration file %s could not be read" % (toolsPath)))
+            finally:
+               fpInfo.close()
+         except (IOError,OSError):
+            self.logger.log(logging.ERROR,getLogMessage("Tools configuration file %s could not be opened" % (toolsPath)))
       else:
          self.logger.log(logging.ERROR,getLogMessage("Tools configuration file %s is missing" % (toolsPath)))
 
+      for toolName in self.tools:
+         markedForDeletion = []
+         for toolGroupIndex in xrange(len(self.tools[toolName])):
+            state = self.tools[toolName][toolGroupIndex]['state']
+            if state == 'disabled':
+               markedForDeletion.append(toolGroupIndex)
+         markedForDeletion.reverse()
+         for toolGroupIndex in markedForDeletion:
+            del self.tools[toolName][toolGroupIndex]
+         del markedForDeletion
+
 
    def applyUserRestriction(self,
                             userName):
