@@ -72,6 +72,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                 tailFiles,
                 enteredCommand,
                 gridsite,
+                pegasusSiteInfo,
                 stageInTarFile,
                 transferExecutable,
                 executable,
@@ -127,9 +128,11 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
       self.destination                      = destination
       self.venue                            = siteInfo['venue']
       self.venuePort                        = siteInfo['venuePort']
+      self.sshOptions                       = siteInfo['sshOptions']
       self.tailFiles                        = tailFiles
       self.enteredCommand                   = enteredCommand
       self.gridsite                         = gridsite
+      self.pegasusSiteInfo                  = pegasusSiteInfo
       self.siteMonitorDesignator            = siteInfo['siteMonitorDesignator']
       self.tunnelDesignator                 = ""
       self.remoteUser                       = siteInfo['remoteUser']
@@ -228,6 +231,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
             if 'x509' in identityPaths:
                if not self.x509SubmitProxy:
                   self.x509SubmitProxy = identityPaths['x509']
+                  self.logger.log(logging.INFO,getLogMessage("IDENTITY = " + self.x509SubmitProxy))
             updateKnownHosts = True
 
          if not exitStatus:
@@ -237,7 +241,7 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                exitStatus,stdOutput,stdError = self.executeCommand(command)
 
          if not exitStatus:
-            self.sshBaseCommand = "gsissh -T -x -a -p %d %s" % (self.venuePort,self.venue)
+            self.sshBaseCommand = "gsissh -T -x -a %s -p %d %s" % (self.sshOptions,self.venuePort,self.venue)
 
 
    def createScripts(self):
@@ -414,8 +418,8 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                                                            self.instanceDirectory,remoteScratchDirectory,
                                                            self.useSetup,self.pegasusVersion,self.pegasusHome,
                                                            self.pegasusTemplates,self.x509SubmitProxy,self.sshIdentityPath,
-                                                           self.gridsite,self.wallTime,
-                                                           self.submissionScriptsInfo,self.timeHistoryLogs)
+                                                           self.gridsite,self.pegasusSiteInfo,self.wallTime,
+                                                           self.siteInfo,self.submissionScriptsInfo,self.timeHistoryLogs)
                   batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildWorkflowScript()
                   batchLogName = ""
                   nodeFileName = ""
@@ -437,8 +441,8 @@ class VenueMechanismGsiSsh(VenueMechanismCore):
                                                      appScriptName,
                                                      self.executable,self.arguments,self.isMultiCoreRequest,
                                                      self.siteInfo,self.submissionScriptsInfo,self.managerInfo,
-                                                     self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.wallTime,
-                                                     self.timeHistoryLogs)
+                                                     self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.pegasusSiteInfo,
+                                                     self.wallTime,self.timeHistoryLogs)
                batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
                nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
                userDaxExecutables = self.remoteBatch.getUserDaxExecutables()
