@@ -70,6 +70,7 @@ class VenueMechanismLocal(VenueMechanismCore):
                 tailFiles,
                 enteredCommand,
                 gridsite,
+                pegasusSiteInfo,
                 stageInTarFile,
                 transferExecutable,
                 executable,
@@ -127,10 +128,10 @@ class VenueMechanismLocal(VenueMechanismCore):
       else:
          self.destination                   = destination
       self.venue                            = siteInfo['venue']
-      self.venuePort                        = siteInfo['venuePort']
       self.tailFiles                        = tailFiles
       self.enteredCommand                   = enteredCommand
       self.gridsite                         = gridsite
+      self.pegasusSiteInfo                  = pegasusSiteInfo
       self.siteMonitorDesignator            = siteInfo['siteMonitorDesignator']
       self.remoteUser                       = siteInfo['remoteUser']
       self.logUserRemotely                  = siteInfo['logUserRemotely']
@@ -225,6 +226,7 @@ class VenueMechanismLocal(VenueMechanismCore):
             if 'x509' in identityPaths:
                if not self.x509SubmitProxy:
                   self.x509SubmitProxy = identityPaths['x509']
+                  self.logger.log(logging.INFO,getLogMessage("IDENTITY = " + self.x509SubmitProxy))
          else:
             identityPaths = self.remoteIdentityManager.queryUserIdentities(self.siteInfo['identityManagers'],
                                                                            self.hubUserName)
@@ -234,6 +236,7 @@ class VenueMechanismLocal(VenueMechanismCore):
             if 'x509' in identityPaths:
                if not self.x509SubmitProxy:
                   self.x509SubmitProxy = identityPaths['x509']
+                  self.logger.log(logging.INFO,getLogMessage("IDENTITY = " + self.x509SubmitProxy))
 
 
    def createScripts(self):
@@ -370,8 +373,8 @@ class VenueMechanismLocal(VenueMechanismCore):
                                                         self.instanceDirectory,remoteScratchDirectory,
                                                         self.useSetup,self.pegasusVersion,self.pegasusHome,
                                                         self.pegasusTemplates,self.x509SubmitProxy,self.sshIdentityPath,
-                                                        self.gridsite,self.wallTime,
-                                                        self.submissionScriptsInfo,self.timeHistoryLogs)
+                                                        self.gridsite,self.pegasusSiteInfo,self.wallTime,
+                                                        self.siteInfo,self.submissionScriptsInfo,self.timeHistoryLogs)
                batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildWorkflowScript()
                batchLogName = ""
                nodeFileName = ""
@@ -393,8 +396,8 @@ class VenueMechanismLocal(VenueMechanismCore):
                                                   appScriptName,
                                                   self.executable,self.arguments,
                                                   self.isMultiCoreRequest,self.siteInfo,self.submissionScriptsInfo,self.managerInfo,
-                                                  self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.wallTime,
-                                                  self.timeHistoryLogs)
+                                                  self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.pegasusSiteInfo,
+                                                  self.wallTime,self.timeHistoryLogs)
             batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
             nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
             userDaxExecutables = self.remoteBatch.getUserDaxExecutables()
