@@ -73,6 +73,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                 tailFiles,
                 enteredCommand,
                 gridsite,
+                pegasusSiteInfo,
                 tunnelsInfo,
                 cloudInstanceId,
                 stageInTarFile,
@@ -133,9 +134,11 @@ class VenueMechanismSsh(VenueMechanismCore):
          self.destination                   = destination
       self.venue                            = siteInfo['venue']
       self.venuePort                        = siteInfo['venuePort']
+      self.sshOptions                       = siteInfo['sshOptions']
       self.tailFiles                        = tailFiles
       self.enteredCommand                   = enteredCommand
       self.gridsite                         = gridsite
+      self.pegasusSiteInfo                  = pegasusSiteInfo
       self.siteMonitorDesignator            = siteInfo['siteMonitorDesignator']
       self.tunnelDesignator                 = siteInfo['tunnelDesignator']
       if self.tunnelDesignator != "":
@@ -257,14 +260,16 @@ class VenueMechanismSsh(VenueMechanismCore):
                         exitStatus,stdOutput,stdError = self.executeCommand(command)
                if not exitStatus:
                   if self.tunnelDesignator == "":
-                     self.sshBaseCommand = "ssh -T -x -a -i %s -p %d %s@%s" % (self.sshIdentityPath,self.venuePort,
-                                                                               self.remoteUser,self.venue)
+                     self.sshBaseCommand = "ssh -T -x -a %s -i %s -p %d %s@%s" % (self.sshOptions,self.sshIdentityPath,
+                                                                                  self.venuePort,
+                                                                                  self.remoteUser,self.venue)
                   else:
                      tunnelAddress,tunnelPort = self.remoteTunnelMonitor.getTunnelAddressPort(self.tunnelDesignator)
-                     self.sshBaseCommand = "ssh -T -x -a -i %s -p %s %s@%s" % (self.sshIdentityPath,tunnelPort,
-                                                                               self.remoteUser,tunnelAddress)
+                     self.sshBaseCommand = "ssh -T -x -a %s -i %s -p %s %s@%s" % (self.sshOptions,self.sshIdentityPath,
+                                                                                  tunnelPort,
+                                                                                  self.remoteUser,tunnelAddress)
             else:
-               self.sshBaseCommand = "ssh -T -x -a -p %d %s@%s" % (self.venuePort,self.remoteUser,self.venue)
+               self.sshBaseCommand = "ssh -T -x -a %s -p %d %s@%s" % (self.sshOptions,self.venuePort,self.remoteUser,self.venue)
 
 
    def createScripts(self):
@@ -459,8 +464,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                            self.instanceDirectory,remoteScratchDirectory,
                                                            self.useSetup,self.pegasusVersion,self.pegasusHome,
                                                            self.pegasusTemplates,self.x509SubmitProxy,self.sshIdentityPath,
-                                                           self.gridsite,self.wallTime,
-                                                           self.submissionScriptsInfo,self.timeHistoryLogs)
+                                                           self.gridsite,self.pegasusSiteInfo,self.wallTime,
+                                                           self.siteInfo,self.submissionScriptsInfo,self.timeHistoryLogs)
                   batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildWorkflowScript()
                   batchLogName = ""
                   nodeFileName = ""
@@ -482,8 +487,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                      appScriptName,
                                                      self.executable,self.arguments,self.isMultiCoreRequest,
                                                      self.siteInfo,self.submissionScriptsInfo,self.managerInfo,
-                                                     self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.wallTime,
-                                                     self.timeHistoryLogs)
+                                                     self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.pegasusSiteInfo,
+                                                     self.wallTime,self.timeHistoryLogs)
                batchLogName,batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildBatchScript()
                nodeFileName,nodeList = self.remoteBatch.getBatchNodeList()
                userDaxExecutables = self.remoteBatch.getUserDaxExecutables()
